@@ -35,23 +35,22 @@
 #' nodes. } \item{plt.clust}{ List. A list of logical values indicating if the
 #' quantization error was met. } \item{summary}{ Summary. Output table with
 #' summary. }
-#' @author Meet K. Dave <dave.kirankumar@@mu-sigma.com>
+#' @author Sangeet Moy Das <Sangeet.Das@@mu-sigma.com>
 #' @seealso \code{\link{hvtHmap}}
 #' @importFrom magrittr %>%
 #' @importFrom stats complete.cases
 #' @examples
 #' 
 #' data("USArrests",package="datasets")
-#' hvqOutput = hvq(USArrests, nclust = 2, depth = 3, quant.err = 0.2,
-#' distance_metric='L1_Norm',error_metric='mean')
+#' hvqOutput = hvq(USArrests, nclust = 3, depth = 3, quant.err = 0.2,
+#' distance_metric = 'L1_Norm', error_metric = 'mean')
 #' 
 #' 
 #' @export hvq
 hvq <-
-  function (x, nclust = 3, depth = 3, quant.err = 10, algorithm = c("Hartigan-Wong", "Lloyd", "Forgy", "MacQueen"),distance_metric = c("L1_Norm","L2_Norm"),error_metric = c("mean","max")) {
+  function (x, nclust = 15, depth = 3, quant.err = 0.2, algorithm = c("Hartigan-Wong", "Lloyd", "Forgy", "MacQueen"),distance_metric = c("L1_Norm","L2_Norm"),error_metric = c("mean","max")) {
     
     requireNamespace("dplyr")
-    
     rescl <- list()
     resid <- list()
     resm <- list()
@@ -60,23 +59,50 @@ hvq <-
     ztab1 <- ztab2 <- ztabn <- NULL
     ztab11 <- ztab12 <- ztab13 <- NULL
     zdepth <- depth
-    quantinit <- rep(F, nclust)
-    # flog.info("Parameters are initialized")
-    #outkinit will have centroids and datapoints and size of the cluster
-    outkinit <- getCentroids(x, kout = stats::kmeans(x, nclust, iter.max=100, algorithm=algorithm), nclust,distance_metric=distance_metric,error_metric=error_metric)
+    quantinit <- rep(FALSE, nclust)
+    
+    set.seed(300)
+    
+    
+    
+    outkinit <- getCentroids(x, kout = stats::kmeans(x, nclust, iter.max=10^5, algorithm=algorithm), nclust,distance_metric,error_metric)
+    
+    # outkinit <- getCentroids(x, kout = stats::kmeans(x, nclust, iter.max=100, algorithm=algorithm), nclust,distance_metric=distance_metric,error_metric=error_metric)
     # flog.info("Level 1 cluster memberships are calculated")
     #datapoints grouped into clusters
+    # names(outkinit$val) <- seq_along(outkinit$val)
     rescl[[1]] <- outkinit$val
     tet <- lapply(outkinit$val, row.names)
-    for (k in 1:length(tet)) tet[[k]] <- data.frame(tet[[k]], 1, 1, k)
+    
+    # tet <- lapply(1:length(tet),function(k){
+    #   data.frame(tet[[as.character(k)]], 1, 1, k)
+    # })
+    # tet <- lapply(1:length(tet),function(k){
+    #   k<- as.character(k)
+    #   if(length(tet[[k]])!=0)
+    #     data.frame(tet[[as.character(k)]], 1, 1, k)
+    #   else data.frame(`tet..as.character.k...`=character(0), `1`=numeric(0),'1'=numeric(0), k=integer(0))
+    # })
+    for (k in 1:length(tet)){
+      #print(k)
+      tet[[k]] <- data.frame(tet[[k]], 1, 1, k)
+      #print(head(tet[[k]]))
+    }
+    names(tet) <- paste(1:length(tet))
+    # names(tet) <- seq_along(tet)
+    # for (k in 1: length(tet)) 
+    #   tet[[as.character(k)]] <- data.frame(tet[[as.character(k)]], 1, 1, k)
     #ID for each datapoint
     resid[[1]] <- tet
     #centroids of each cluster
+    # names(outkinit$cent) <- seq_along(outkinit$cent)
     resm[[1]] <- outkinit$cent
     #flag to check for quantization error
     resplt[[1]] <- unlist(outkinit$cent) > quant.err
     #initial values for next level k-means
+    # names(outkinit$values)<-seq_along(outkinit$values)
     initclust <- outkinit$values
+
     if (depth > 1) {
       # flog.info("HVQ calculation started")
       i <- 1
@@ -97,34 +123,66 @@ hvq <-
         quantok <- unlist(resplt[[i]])
         j <- 1
         while (j < (nclust^i) + 1) {
+          
+          # print(paste("im hererrrrrrrrrrrr",j))
           #if datapoint exceeds quantization error and number of datapoints in
           #that cluster is greater than nclust
-          if (quantok[j] & NROW(initclust[[j]]) > nclust) {
+          if (quantok[j] & 
+              NROW(initclust[[j]]) > 3
+              ) {
             #k-means on the initclust to obtain the next level clustering(sub-clusters)
-            outk <- getCentroids(initclust[[j]], kout = stats::kmeans(initclust[[j]], 
-                                                               nclust, iter.max = 100, algorithm = algorithm), nclust,distance_metric = distance_metric,error_metric = error_metric)
+            z =data.frame(initclust[[j]])
+            # try(
+            outk <- getOptimalCentroids(z, iter.max = 10^5, algorithm = algorithm, nclust,distance_metric,error_metric,quant.err = quant.err)
+            # )
+            # outk <- getOptimalCentroids(initclust[[j]], iter.max = 100, algorithm = algorithm, nclust,distance_metric = distance_metric,error_metric = error_metric,quant.err = quant.err)
+            
+            # outk <- getCentroids(initclust[[j]], kout = stats::kmeans(initclust[[j]], nclust, iter.max = 100, algorithm = algorithm), nclust,distance_metric = distance_metric,error_metric = error_metric)
             #store the datapoints
+            # names(outk$val)<-seq_along(outk$val)
             ijrescl[[j]] <- outk$val
+            # tet <- lapply(outk$val, sapply, row.names)
             tet <- lapply(outk$val, row.names)
+            # names(tet) <- seq_along(tet)
             #create ID's for each datapoint
-            for (k in 1: length(tet)) tet[[k]] <- data.frame(tet[[k]], 
-                                                             i + 1, j, k)
+            # tet <- lapply(1:length(tet),function(k){
+            #   if(length(tet[[as.character(k)]])!=0)
+            #     data.frame(tet[[as.character(k)]], i+1, j, k)
+            #   else data.frame(`tet..as.character.k...`=character(0), `i...1`=numeric(0), j=numeric(0), k=integer(0))
+            # })
+            # for (k in 1: length(tet)) {
+            #   print(k)
+            #   print(nrow(data.frame(tet[[k]])))
+            # }
+            for (k in 1: length(tet)){
+              
+              if(!is.null(tet[[k]])){
+                tet[[k]] <- data.frame(tet[[k]],i + 1, j, k)  
+              }
+              else{
+                tet[[k]] <- data.frame(tet[[k]]<-numeric(0))
+              }
+            }
+            
+            # names(tet) <- paste(1:length(tet))
+            # names(tet)<-seq_along(tet)
             ijresid[[j]] <- tet
             #store the centroids
-            ijresm[[j]] <- outk$cent
+            # names(outk$cent) <- seq_along(outk$cent)
+            ijresm[[j]] <- outk$centers
             #size of a cluster
+            # names(outk$nsize) <- seq_along(outk$nsize)
             ijresnsize[[j]] <- outk$nsize
             # ijztab3up[[j]] <- sapply(outk$val, mean)
             
             ijztab3up[[j]]<-matrix(0, nrow = ncol(x), nclust)
-            for(a in 1: nclust){
-              for(b in 1: ncol(x)){
-                ijztab3up[[j]][b, a] <- as.matrix(mean(outk$val[[a]][, b]))
-                rownames(ijztab3up[[j]]) <- colnames(x)
-              }
-            }
+            
+            # rownames(ijztab3up[[j]]) <- colnames(x)
+            ijztab3up[[j]] <- t(outk$centroid_val)
+            # ijztab3up[[j]]<- na.omit(ijztab3up[[j]])
+            
             #flag to check if the quantization error threshold is exceeded
-            ijresplt[[j]] <- unlist(outk$cent) > quant.err
+            ijresplt[[j]] <- unlist(outk$centers) > quant.err
             #store the datapoints
             ijclust <- c(ijclust, outk$values)
           }else {
@@ -133,7 +191,7 @@ hvq <-
             ijresm[[j]] <- rep(NA, nclust)
             ijresnsize[[j]] <- rep(0, nclust)
             ijztab3up[[j]] <- matrix(NA, ncol(x), nclust)
-            ijresplt[[j]] <- rep(F, nclust)
+            ijresplt[[j]] <- rep(FALSE, nclust)
             ijclust <- c(ijclust, rep(NA, nclust))
           }
           ztab1 <- c(ztab1, paste(i + 1, j, 1:nclust, sep = ","))
@@ -153,7 +211,7 @@ hvq <-
         # flog.info("Output for Level %s is ready", i)
         i <- i + 1
         #check if the desired depth is reached
-        if (!is.element(T, unlist(ijresplt))) {
+        if (!is.element(TRUE, unlist(ijresplt))) {
           zdepth <- i
           i <- depth
         }
@@ -173,16 +231,17 @@ hvq <-
       ztab[1:nclust, 4] <- unlist(outkinit$nsize)
       #Centroid/Quantization error of the cluster
       ztab[1:nclust, 5] <- unlist(outkinit$cent)
-      # ztab3upc <- sapply(outkinit$val, mean, na.rm = T)
+      # ztab3upc <- sapply(outkinit$val, mean, na.rm = TRUE)
       ztab3upc<-matrix(0, nrow = ncol(x), nclust)
       for(a in 1: nclust){
         for(b in 1: ncol(x)){
-          ztab3upc[b, a] <- as.matrix(mean(outkinit$val[[a]][, b], na.rm = T))
+          ztab3upc[b, a] <- as.matrix(mean(outkinit$val[[a]][, b], na.rm = TRUE))
           rownames(ztab3upc) <- colnames(x)
         }
       }
       for (l in 1:length(ztab3up)) ztab3upc <- cbind(ztab3upc, 
                                                      ztab3up[[l]])
+        
       ztab[(nclust + 1):sum(nclust^(1:zdepth)), 1] <- ztab11
       ztab[(nclust + 1):sum(nclust^(1:zdepth)), 2] <- ztab12
       ztab[(nclust + 1):sum(nclust^(1:zdepth)), 3] <- ztab13
@@ -191,8 +250,7 @@ hvq <-
       ztab[(nclust + 1): sum(nclust^(1: zdepth)), 5] <- ztabn
       names(ztab) <- c("Segment.Level", "Segment.Parent", "Segment.Child", 
                        "n", "Quant.Error", colnames(x))
-    }
-    else {
+    } else {
       ztab <- data.frame(matrix(0, nrow = nclust, ncol = (ncol(x) + 
                                                             5)))
       ztab[, 1] <- rep(1, nclust)
@@ -200,12 +258,17 @@ hvq <-
       ztab[, 3] <- 1:nclust
       ztab[, 4] <- unlist(outkinit$nsize)
       ztab[, 6:ncol(ztab)] <- t(sapply(outkinit$val, colMeans, 
-                                       na.rm = T))
+                                       na.rm = TRUE))
       ztab[, 5] <- unlist(outkinit$cent)
       names(ztab) <- c("Segment.Level", "Segment.Parent", "Segment.Child", 
                        "n", "Quant.Error", colnames(x))
     }
     
+    
+    
+    
+    
+    
     ## Calculate compress percentage
     compression_summary <- ztab %>% dplyr::group_by(Segment.Level) %>% dplyr::summarise(noOfCells = sum(!is.na(Quant.Error)), noOfCellsBelowQuantizationError = sum(Quant.Error < quant.err,na.rm = TRUE)) %>% dplyr::mutate(percentOfCellsBelowQuantizationErrorThreshold = (noOfCellsBelowQuantizationError/noOfCells))
     
